'''_3611.py

BevelDifferentialGearSetCompoundParametricStudyTool
'''


from typing import List

from mastapy.system_model.part_model.gears import _2055
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.parametric_study_tools.compound import _3609, _3610, _3616
from mastapy.system_model.analyses_and_results.parametric_study_tools import _3474
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound', 'BevelDifferentialGearSetCompoundParametricStudyTool')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearSetCompoundParametricStudyTool',)


class BevelDifferentialGearSetCompoundParametricStudyTool(_3616.BevelGearSetCompoundParametricStudyTool):
    '''BevelDifferentialGearSetCompoundParametricStudyTool

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_SET_COMPOUND_PARAMETRIC_STUDY_TOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearSetCompoundParametricStudyTool.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2055.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2055.BevelDifferentialGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2055.BevelDifferentialGearSet':
        '''BevelDifferentialGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2055.BevelDifferentialGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def bevel_differential_gears_compound_parametric_study_tool(self) -> 'List[_3609.BevelDifferentialGearCompoundParametricStudyTool]':
        '''List[BevelDifferentialGearCompoundParametricStudyTool]: 'BevelDifferentialGearsCompoundParametricStudyTool' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialGearsCompoundParametricStudyTool, constructor.new(_3609.BevelDifferentialGearCompoundParametricStudyTool))
        return value

    @property
    def bevel_differential_meshes_compound_parametric_study_tool(self) -> 'List[_3610.BevelDifferentialGearMeshCompoundParametricStudyTool]':
        '''List[BevelDifferentialGearMeshCompoundParametricStudyTool]: 'BevelDifferentialMeshesCompoundParametricStudyTool' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BevelDifferentialMeshesCompoundParametricStudyTool, constructor.new(_3610.BevelDifferentialGearMeshCompoundParametricStudyTool))
        return value

    @property
    def load_case_analyses_ready(self) -> 'List[_3474.BevelDifferentialGearSetParametricStudyTool]':
        '''List[BevelDifferentialGearSetParametricStudyTool]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_3474.BevelDifferentialGearSetParametricStudyTool))
        return value

    @property
    def assembly_parametric_study_tool_load_cases(self) -> 'List[_3474.BevelDifferentialGearSetParametricStudyTool]':
        '''List[BevelDifferentialGearSetParametricStudyTool]: 'AssemblyParametricStudyToolLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyParametricStudyToolLoadCases, constructor.new(_3474.BevelDifferentialGearSetParametricStudyTool))
        return value



'''_1482.py

ElementPropertiesSolid
'''


from mastapy.nodal_analysis.dev_tools_analyses.full_fe_reporting import _1484
from mastapy._internal.python_net import python_net_import

_ELEMENT_PROPERTIES_SOLID = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.FullFEReporting', 'ElementPropertiesSolid')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementPropertiesSolid',)


class ElementPropertiesSolid(_1484.ElementPropertiesWithMaterial):
    '''ElementPropertiesSolid

    This is a mastapy class.
    '''

    TYPE = _ELEMENT_PROPERTIES_SOLID

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElementPropertiesSolid.TYPE'):
        super().__init__(instance_to_wrap)



'''_6058.py

BevelDifferentialGearMeshLoadCase
'''


from mastapy.system_model.connections_and_sockets.gears import _1862
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6063
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_MESH_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'BevelDifferentialGearMeshLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearMeshLoadCase',)


class BevelDifferentialGearMeshLoadCase(_6063.BevelGearMeshLoadCase):
    '''BevelDifferentialGearMeshLoadCase

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_MESH_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearMeshLoadCase.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connection_design(self) -> '_1862.BevelDifferentialGearMesh':
        '''BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1862.BevelDifferentialGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._245 import GleasonHypoidGearSingleFlankRating
    from ._246 import GleasonHypoidMeshSingleFlankRating
    from ._247 import HypoidRateableMesh



'''_5975.py

HypoidGearSetCompoundDynamicAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2074
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import _5973, _5974, _5922
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5854
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_SET_COMPOUND_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses.Compound', 'HypoidGearSetCompoundDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearSetCompoundDynamicAnalysis',)


class HypoidGearSetCompoundDynamicAnalysis(_5922.AGMAGleasonConicalGearSetCompoundDynamicAnalysis):
    '''HypoidGearSetCompoundDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_SET_COMPOUND_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearSetCompoundDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2074.HypoidGearSet':
        '''HypoidGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2074.HypoidGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2074.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2074.HypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def hypoid_gears_compound_dynamic_analysis(self) -> 'List[_5973.HypoidGearCompoundDynamicAnalysis]':
        '''List[HypoidGearCompoundDynamicAnalysis]: 'HypoidGearsCompoundDynamicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearsCompoundDynamicAnalysis, constructor.new(_5973.HypoidGearCompoundDynamicAnalysis))
        return value

    @property
    def hypoid_meshes_compound_dynamic_analysis(self) -> 'List[_5974.HypoidGearMeshCompoundDynamicAnalysis]':
        '''List[HypoidGearMeshCompoundDynamicAnalysis]: 'HypoidMeshesCompoundDynamicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidMeshesCompoundDynamicAnalysis, constructor.new(_5974.HypoidGearMeshCompoundDynamicAnalysis))
        return value

    @property
    def load_case_analyses_ready(self) -> 'List[_5854.HypoidGearSetDynamicAnalysis]':
        '''List[HypoidGearSetDynamicAnalysis]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_5854.HypoidGearSetDynamicAnalysis))
        return value

    @property
    def assembly_dynamic_analysis_load_cases(self) -> 'List[_5854.HypoidGearSetDynamicAnalysis]':
        '''List[HypoidGearSetDynamicAnalysis]: 'AssemblyDynamicAnalysisLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyDynamicAnalysisLoadCases, constructor.new(_5854.HypoidGearSetDynamicAnalysis))
        return value



'''_1079.py

ComplexMagnitudeMethod
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_COMPLEX_MAGNITUDE_METHOD = python_net_import('SMT.MastaAPI.MathUtility', 'ComplexMagnitudeMethod')


__docformat__ = 'restructuredtext en'
__all__ = ('ComplexMagnitudeMethod',)


class ComplexMagnitudeMethod(Enum):
    '''ComplexMagnitudeMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _COMPLEX_MAGNITUDE_METHOD

    __hash__ = None

    MAXIMUM_MAGNITUDE_OVER_PERIOD = 0
    MAGNITUDE_OF_COMPLEX_MODULI = 1
    MAGNITUDE_OF_COMPLEX_VALUES = 2



'''_5584.py

GearSetCompoundSingleMeshWhineAnalysis
'''


from mastapy.system_model.analyses_and_results.gear_whine_analyses.single_mesh_whine_analyses.compound import _5621
from mastapy._internal.python_net import python_net_import

_GEAR_SET_COMPOUND_SINGLE_MESH_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.SingleMeshWhineAnalyses.Compound', 'GearSetCompoundSingleMeshWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('GearSetCompoundSingleMeshWhineAnalysis',)


class GearSetCompoundSingleMeshWhineAnalysis(_5621.SpecialisedAssemblyCompoundSingleMeshWhineAnalysis):
    '''GearSetCompoundSingleMeshWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _GEAR_SET_COMPOUND_SINGLE_MESH_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearSetCompoundSingleMeshWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)



'''_5124.py

BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis
'''


from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5120
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_SUN_GEAR_COMPOUND_MULTI_BODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis',)


class BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis(_5120.BevelDifferentialGearCompoundMultiBodyDynamicsAnalysis):
    '''BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_SUN_GEAR_COMPOUND_MULTI_BODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialSunGearCompoundMultiBodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)



'''_495.py

FormWheelGrindingSimulationCalculator
'''


from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.cutters.tangibles import _527
from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _488
from mastapy._internal.python_net import python_net_import

_FORM_WHEEL_GRINDING_SIMULATION_CALCULATOR = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.CutterSimulation', 'FormWheelGrindingSimulationCalculator')


__docformat__ = 'restructuredtext en'
__all__ = ('FormWheelGrindingSimulationCalculator',)


class FormWheelGrindingSimulationCalculator(_488.CutterSimulationCalc):
    '''FormWheelGrindingSimulationCalculator

    This is a mastapy class.
    '''

    TYPE = _FORM_WHEEL_GRINDING_SIMULATION_CALCULATOR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FormWheelGrindingSimulationCalculator.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def centre_distance(self) -> 'float':
        '''float: 'CentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CentreDistance

    @property
    def profiled_grinding_wheel(self) -> '_527.CylindricalGearFormedWheelGrinderTangible':
        '''CylindricalGearFormedWheelGrinderTangible: 'ProfiledGrindingWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_527.CylindricalGearFormedWheelGrinderTangible)(self.wrapped.ProfiledGrindingWheel) if self.wrapped.ProfiledGrindingWheel else None



'''_1817.py

CylindricalGearOptimizationStep
'''


from mastapy._internal import constructor
from mastapy.system_model.optimization import _1821
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_OPTIMIZATION_STEP = python_net_import('SMT.MastaAPI.SystemModel.Optimization', 'CylindricalGearOptimizationStep')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearOptimizationStep',)


class CylindricalGearOptimizationStep(_1821.OptimizationStep):
    '''CylindricalGearOptimizationStep

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_OPTIMIZATION_STEP

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearOptimizationStep.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def use_advanced_ltca(self) -> 'bool':
        '''bool: 'UseAdvancedLTCA' is the original name of this property.'''

        return self.wrapped.UseAdvancedLTCA

    @use_advanced_ltca.setter
    def use_advanced_ltca(self, value: 'bool'):
        self.wrapped.UseAdvancedLTCA = bool(value) if value else False

    @property
    def include_extended_tip_contact(self) -> 'bool':
        '''bool: 'IncludeExtendedTipContact' is the original name of this property.'''

        return self.wrapped.IncludeExtendedTipContact

    @include_extended_tip_contact.setter
    def include_extended_tip_contact(self, value: 'bool'):
        self.wrapped.IncludeExtendedTipContact = bool(value) if value else False

    @property
    def include_tip_edge_stresses(self) -> 'bool':
        '''bool: 'IncludeTipEdgeStresses' is the original name of this property.'''

        return self.wrapped.IncludeTipEdgeStresses

    @include_tip_edge_stresses.setter
    def include_tip_edge_stresses(self, value: 'bool'):
        self.wrapped.IncludeTipEdgeStresses = bool(value) if value else False



'''_5096.py

UnbalancedMassMultiBodyDynamicsAnalysis
'''


from typing import List

from mastapy.system_model.part_model import _2018
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6207
from mastapy.system_model.analyses_and_results.mbd_analyses import _5097
from mastapy._internal.python_net import python_net_import

_UNBALANCED_MASS_MULTI_BODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'UnbalancedMassMultiBodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('UnbalancedMassMultiBodyDynamicsAnalysis',)


class UnbalancedMassMultiBodyDynamicsAnalysis(_5097.VirtualComponentMultiBodyDynamicsAnalysis):
    '''UnbalancedMassMultiBodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _UNBALANCED_MASS_MULTI_BODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'UnbalancedMassMultiBodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2018.UnbalancedMass':
        '''UnbalancedMass: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2018.UnbalancedMass)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6207.UnbalancedMassLoadCase':
        '''UnbalancedMassLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6207.UnbalancedMassLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def planetaries(self) -> 'List[UnbalancedMassMultiBodyDynamicsAnalysis]':
        '''List[UnbalancedMassMultiBodyDynamicsAnalysis]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(UnbalancedMassMultiBodyDynamicsAnalysis))
        return value



'''_145.py

PocketingPowerLossCoefficients
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.math_utility import _1072
from mastapy.gears import _149
from mastapy.utility.databases import _1342
from mastapy._internal.python_net import python_net_import

_POCKETING_POWER_LOSS_COEFFICIENTS = python_net_import('SMT.MastaAPI.Gears', 'PocketingPowerLossCoefficients')


__docformat__ = 'restructuredtext en'
__all__ = ('PocketingPowerLossCoefficients',)


class PocketingPowerLossCoefficients(_1342.NamedDatabaseItem):
    '''PocketingPowerLossCoefficients

    This is a mastapy class.
    '''

    TYPE = _POCKETING_POWER_LOSS_COEFFICIENTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PocketingPowerLossCoefficients.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def reference_gear_outer_diameter(self) -> 'float':
        '''float: 'ReferenceGearOuterDiameter' is the original name of this property.'''

        return self.wrapped.ReferenceGearOuterDiameter

    @reference_gear_outer_diameter.setter
    def reference_gear_outer_diameter(self, value: 'float'):
        self.wrapped.ReferenceGearOuterDiameter = float(value) if value else 0.0

    @property
    def reference_gear_pocket_dimension(self) -> 'float':
        '''float: 'ReferenceGearPocketDimension' is the original name of this property.'''

        return self.wrapped.ReferenceGearPocketDimension

    @reference_gear_pocket_dimension.setter
    def reference_gear_pocket_dimension(self, value: 'float'):
        self.wrapped.ReferenceGearPocketDimension = float(value) if value else 0.0

    @property
    def extrapolation_options(self) -> 'enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions':
        '''enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions: 'ExtrapolationOptions' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.ExtrapolationOptions, value) if self.wrapped.ExtrapolationOptions else None

    @extrapolation_options.setter
    def extrapolation_options(self, value: 'enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.ExtrapolationOptions = value

    @property
    def slope_of_linear_equation_defining_the_effect_of_gear_face_width(self) -> 'float':
        '''float: 'SlopeOfLinearEquationDefiningTheEffectOfGearFaceWidth' is the original name of this property.'''

        return self.wrapped.SlopeOfLinearEquationDefiningTheEffectOfGearFaceWidth

    @slope_of_linear_equation_defining_the_effect_of_gear_face_width.setter
    def slope_of_linear_equation_defining_the_effect_of_gear_face_width(self, value: 'float'):
        self.wrapped.SlopeOfLinearEquationDefiningTheEffectOfGearFaceWidth = float(value) if value else 0.0

    @property
    def intercept_of_linear_equation_defining_the_effect_of_gear_face_width(self) -> 'float':
        '''float: 'InterceptOfLinearEquationDefiningTheEffectOfGearFaceWidth' is the original name of this property.'''

        return self.wrapped.InterceptOfLinearEquationDefiningTheEffectOfGearFaceWidth

    @intercept_of_linear_equation_defining_the_effect_of_gear_face_width.setter
    def intercept_of_linear_equation_defining_the_effect_of_gear_face_width(self, value: 'float'):
        self.wrapped.InterceptOfLinearEquationDefiningTheEffectOfGearFaceWidth = float(value) if value else 0.0

    @property
    def upper_bound_for_oil_kinematic_viscosity(self) -> 'float':
        '''float: 'UpperBoundForOilKinematicViscosity' is the original name of this property.'''

        return self.wrapped.UpperBoundForOilKinematicViscosity

    @upper_bound_for_oil_kinematic_viscosity.setter
    def upper_bound_for_oil_kinematic_viscosity(self, value: 'float'):
        self.wrapped.UpperBoundForOilKinematicViscosity = float(value) if value else 0.0

    @property
    def lower_bound_for_oil_kinematic_viscosity(self) -> 'float':
        '''float: 'LowerBoundForOilKinematicViscosity' is the original name of this property.'''

        return self.wrapped.LowerBoundForOilKinematicViscosity

    @lower_bound_for_oil_kinematic_viscosity.setter
    def lower_bound_for_oil_kinematic_viscosity(self, value: 'float'):
        self.wrapped.LowerBoundForOilKinematicViscosity = float(value) if value else 0.0

    @property
    def slope_of_linear_equation_defining_the_effect_of_helix_angle(self) -> 'float':
        '''float: 'SlopeOfLinearEquationDefiningTheEffectOfHelixAngle' is the original name of this property.'''

        return self.wrapped.SlopeOfLinearEquationDefiningTheEffectOfHelixAngle

    @slope_of_linear_equation_defining_the_effect_of_helix_angle.setter
    def slope_of_linear_equation_defining_the_effect_of_helix_angle(self, value: 'float'):
        self.wrapped.SlopeOfLinearEquationDefiningTheEffectOfHelixAngle = float(value) if value else 0.0

    @property
    def intercept_of_linear_equation_defining_the_effect_of_helix_angle(self) -> 'float':
        '''float: 'InterceptOfLinearEquationDefiningTheEffectOfHelixAngle' is the original name of this property.'''

        return self.wrapped.InterceptOfLinearEquationDefiningTheEffectOfHelixAngle

    @intercept_of_linear_equation_defining_the_effect_of_helix_angle.setter
    def intercept_of_linear_equation_defining_the_effect_of_helix_angle(self, value: 'float'):
        self.wrapped.InterceptOfLinearEquationDefiningTheEffectOfHelixAngle = float(value) if value else 0.0

    @property
    def specifications_for_the_effect_of_oil_kinematic_viscosity(self) -> 'List[_149.SpecificationForTheEffectOfOilKinematicViscosity]':
        '''List[SpecificationForTheEffectOfOilKinematicViscosity]: 'SpecificationsForTheEffectOfOilKinematicViscosity' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpecificationsForTheEffectOfOilKinematicViscosity, constructor.new(_149.SpecificationForTheEffectOfOilKinematicViscosity))
        return value



'''_810.py

ISO6336GeometryForShapedGears
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical import _809
from mastapy._internal.python_net import python_net_import

_ISO6336_GEOMETRY_FOR_SHAPED_GEARS = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical', 'ISO6336GeometryForShapedGears')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO6336GeometryForShapedGears',)


class ISO6336GeometryForShapedGears(_809.ISO6336GeometryBase):
    '''ISO6336GeometryForShapedGears

    This is a mastapy class.
    '''

    TYPE = _ISO6336_GEOMETRY_FOR_SHAPED_GEARS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO6336GeometryForShapedGears.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def equivalent_numbers_of_teeth(self) -> 'float':
        '''float: 'EquivalentNumbersOfTeeth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EquivalentNumbersOfTeeth

    @property
    def working_pressure_angle(self) -> 'float':
        '''float: 'WorkingPressureAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WorkingPressureAngle

    @property
    def manufacturing_centre_distance(self) -> 'float':
        '''float: 'ManufacturingCentreDistance' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ManufacturingCentreDistance

    @property
    def manufacturing_tooth_ratio(self) -> 'float':
        '''float: 'ManufacturingToothRatio' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ManufacturingToothRatio

    @property
    def cutting_pitch_radius_of_the_gear(self) -> 'float':
        '''float: 'CuttingPitchRadiusOfTheGear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CuttingPitchRadiusOfTheGear

    @property
    def cutting_pitch_radius_of_the_tool(self) -> 'float':
        '''float: 'CuttingPitchRadiusOfTheTool' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CuttingPitchRadiusOfTheTool

    @property
    def base_radius_of_the_tool(self) -> 'float':
        '''float: 'BaseRadiusOfTheTool' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BaseRadiusOfTheTool

    @property
    def radius_of_point_m(self) -> 'float':
        '''float: 'RadiusOfPointM' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadiusOfPointM

    @property
    def transverse_pressure_angle_for_radius_of_point_m(self) -> 'float':
        '''float: 'TransversePressureAngleForRadiusOfPointM' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransversePressureAngleForRadiusOfPointM

    @property
    def half_angle_of_thickness_at_point_m(self) -> 'float':
        '''float: 'HalfAngleOfThicknessAtPointM' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HalfAngleOfThicknessAtPointM

    @property
    def theta(self) -> 'float':
        '''float: 'Theta' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Theta

    @property
    def auxiliary_angle(self) -> 'float':
        '''float: 'AuxiliaryAngle' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryAngle

    @property
    def distance_of_the_point_m_to_the_point_of_contact_of_the_pitch_circles(self) -> 'float':
        '''float: 'DistanceOfThePointMToThePointOfContactOfThePitchCircles' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceOfThePointMToThePointOfContactOfThePitchCircles

    @property
    def tooth_root_thickness(self) -> 'float':
        '''float: 'ToothRootThickness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootThickness

    @property
    def tooth_root_fillet_radius(self) -> 'float':
        '''float: 'ToothRootFilletRadius' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothRootFilletRadius



'''_349.py

SpiralBevelRateableGear
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_RATEABLE_GEAR = python_net_import('SMT.MastaAPI.Gears.Rating.Bevel.Standards', 'SpiralBevelRateableGear')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelRateableGear',)


class SpiralBevelRateableGear(_0.APIBase):
    '''SpiralBevelRateableGear

    This is a mastapy class.
    '''

    TYPE = _SPIRAL_BEVEL_RATEABLE_GEAR

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelRateableGear.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def gear_blank_temperature(self) -> 'float':
        '''float: 'GearBlankTemperature' is the original name of this property.'''

        return self.wrapped.GearBlankTemperature

    @gear_blank_temperature.setter
    def gear_blank_temperature(self, value: 'float'):
        self.wrapped.GearBlankTemperature = float(value) if value else 0.0



'''_542.py

PlungeShaverRedressing
'''


from mastapy.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import _549, _540
from mastapy._internal.python_net import python_net_import

_PLUNGE_SHAVER_REDRESSING = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics', 'PlungeShaverRedressing')


__docformat__ = 'restructuredtext en'
__all__ = ('PlungeShaverRedressing',)


class PlungeShaverRedressing(_549.ShaverRedressing['_540.PlungeShaverDynamics']):
    '''PlungeShaverRedressing

    This is a mastapy class.
    '''

    TYPE = _PLUNGE_SHAVER_REDRESSING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlungeShaverRedressing.TYPE'):
        super().__init__(instance_to_wrap)



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2478 import AbstractAssemblySteadyStateSynchronousResponseOnAShaft
    from ._2479 import AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft
    from ._2480 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2481 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2482 import AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft
    from ._2483 import AssemblySteadyStateSynchronousResponseOnAShaft
    from ._2484 import BearingSteadyStateSynchronousResponseOnAShaft
    from ._2485 import BeltConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2486 import BeltDriveSteadyStateSynchronousResponseOnAShaft
    from ._2487 import BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2488 import BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2489 import BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft
    from ._2490 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._2491 import BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft
    from ._2492 import BevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2493 import BevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2494 import BevelGearSteadyStateSynchronousResponseOnAShaft
    from ._2495 import BoltedJointSteadyStateSynchronousResponseOnAShaft
    from ._2496 import BoltSteadyStateSynchronousResponseOnAShaft
    from ._2497 import ClutchConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2498 import ClutchHalfSteadyStateSynchronousResponseOnAShaft
    from ._2499 import ClutchSteadyStateSynchronousResponseOnAShaft
    from ._2500 import CoaxialConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2501 import ComponentSteadyStateSynchronousResponseOnAShaft
    from ._2502 import ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2503 import ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._2504 import ConceptCouplingSteadyStateSynchronousResponseOnAShaft
    from ._2505 import ConceptGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2506 import ConceptGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2507 import ConceptGearSteadyStateSynchronousResponseOnAShaft
    from ._2508 import ConicalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2509 import ConicalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2510 import ConicalGearSteadyStateSynchronousResponseOnAShaft
    from ._2511 import ConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2512 import ConnectorSteadyStateSynchronousResponseOnAShaft
    from ._2513 import CouplingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2514 import CouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._2515 import CouplingSteadyStateSynchronousResponseOnAShaft
    from ._2516 import CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2517 import CVTPulleySteadyStateSynchronousResponseOnAShaft
    from ._2518 import CVTSteadyStateSynchronousResponseOnAShaft
    from ._2519 import CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2520 import CylindricalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2521 import CylindricalGearSteadyStateSynchronousResponseOnAShaft
    from ._2522 import CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._2523 import DatumSteadyStateSynchronousResponseOnAShaft
    from ._2524 import ExternalCADModelSteadyStateSynchronousResponseOnAShaft
    from ._2525 import FaceGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2526 import FaceGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2527 import FaceGearSteadyStateSynchronousResponseOnAShaft
    from ._2528 import FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft
    from ._2529 import GearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2530 import GearSetSteadyStateSynchronousResponseOnAShaft
    from ._2531 import GearSteadyStateSynchronousResponseOnAShaft
    from ._2532 import GuideDxfModelSteadyStateSynchronousResponseOnAShaft
    from ._2533 import HypoidGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2534 import HypoidGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2535 import HypoidGearSteadyStateSynchronousResponseOnAShaft
    from ._2536 import ImportedFEComponentSteadyStateSynchronousResponseOnAShaft
    from ._2537 import InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2538 import KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2539 import KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2540 import KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft
    from ._2541 import KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2542 import KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2543 import KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft
    from ._2544 import KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2545 import KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2546 import KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft
    from ._2547 import MassDiscSteadyStateSynchronousResponseOnAShaft
    from ._2548 import MeasurementComponentSteadyStateSynchronousResponseOnAShaft
    from ._2549 import MountableComponentSteadyStateSynchronousResponseOnAShaft
    from ._2550 import OilSealSteadyStateSynchronousResponseOnAShaft
    from ._2551 import PartSteadyStateSynchronousResponseOnAShaft
    from ._2552 import PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2553 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._2554 import PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft
    from ._2555 import PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2556 import PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2557 import PlanetCarrierSteadyStateSynchronousResponseOnAShaft
    from ._2558 import PointLoadSteadyStateSynchronousResponseOnAShaft
    from ._2559 import PowerLoadSteadyStateSynchronousResponseOnAShaft
    from ._2560 import PulleySteadyStateSynchronousResponseOnAShaft
    from ._2561 import RollingRingAssemblySteadyStateSynchronousResponseOnAShaft
    from ._2562 import RollingRingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2563 import RollingRingSteadyStateSynchronousResponseOnAShaft
    from ._2564 import RootAssemblySteadyStateSynchronousResponseOnAShaft
    from ._2565 import ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2566 import ShaftSteadyStateSynchronousResponseOnAShaft
    from ._2567 import ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2568 import SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft
    from ._2569 import SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2570 import SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2571 import SpiralBevelGearSteadyStateSynchronousResponseOnAShaft
    from ._2572 import SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2573 import SpringDamperHalfSteadyStateSynchronousResponseOnAShaft
    from ._2574 import SpringDamperSteadyStateSynchronousResponseOnAShaft
    from ._2575 import SteadyStateSynchronousResponseOnAShaft
    from ._2576 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2577 import StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2578 import StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft
    from ._2579 import StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2580 import StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2581 import StraightBevelGearSteadyStateSynchronousResponseOnAShaft
    from ._2582 import StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._2583 import StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft
    from ._2584 import SynchroniserHalfSteadyStateSynchronousResponseOnAShaft
    from ._2585 import SynchroniserPartSteadyStateSynchronousResponseOnAShaft
    from ._2586 import SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft
    from ._2587 import SynchroniserSteadyStateSynchronousResponseOnAShaft
    from ._2588 import TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft
    from ._2589 import TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft
    from ._2590 import TorqueConverterSteadyStateSynchronousResponseOnAShaft
    from ._2591 import TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft
    from ._2592 import UnbalancedMassSteadyStateSynchronousResponseOnAShaft
    from ._2593 import VirtualComponentSteadyStateSynchronousResponseOnAShaft
    from ._2594 import WormGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2595 import WormGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2596 import WormGearSteadyStateSynchronousResponseOnAShaft
    from ._2597 import ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._2598 import ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._2599 import ZerolBevelGearSteadyStateSynchronousResponseOnAShaft



'''_1926.py

ElementFaceGroupWithSelection
'''


from mastapy.system_model.imported_fes import _1929
from mastapy.nodal_analysis.component_mode_synthesis import _1487
from mastapy.fe_tools.vis_tools_global import _963
from mastapy._internal.python_net import python_net_import

_ELEMENT_FACE_GROUP_WITH_SELECTION = python_net_import('SMT.MastaAPI.SystemModel.ImportedFEs', 'ElementFaceGroupWithSelection')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementFaceGroupWithSelection',)


class ElementFaceGroupWithSelection(_1929.FEEntityGroupWithSelection['_1487.CMSElementFaceGroup', '_963.ElementFace']):
    '''ElementFaceGroupWithSelection

    This is a mastapy class.
    '''

    TYPE = _ELEMENT_FACE_GROUP_WITH_SELECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElementFaceGroupWithSelection.TYPE'):
        super().__init__(instance_to_wrap)



'''_4834.py

CampbellDiagramReport
'''


from mastapy.utility.report import _1278
from mastapy._internal.python_net import python_net_import

_CAMPBELL_DIAGRAM_REPORT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting', 'CampbellDiagramReport')


__docformat__ = 'restructuredtext en'
__all__ = ('CampbellDiagramReport',)


class CampbellDiagramReport(_1278.CustomReportChart):
    '''CampbellDiagramReport

    This is a mastapy class.
    '''

    TYPE = _CAMPBELL_DIAGRAM_REPORT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CampbellDiagramReport.TYPE'):
        super().__init__(instance_to_wrap)



'''_5479.py

ModalAnalysisForWhine
'''


from mastapy.system_model.analyses_and_results.modal_analyses import _4772
from mastapy._internal.python_net import python_net_import

_MODAL_ANALYSIS_FOR_WHINE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.SingleMeshWhineAnalyses', 'ModalAnalysisForWhine')


__docformat__ = 'restructuredtext en'
__all__ = ('ModalAnalysisForWhine',)


class ModalAnalysisForWhine(_4772.ModalAnalysis):
    '''ModalAnalysisForWhine

    This is a mastapy class.
    '''

    TYPE = _MODAL_ANALYSIS_FOR_WHINE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ModalAnalysisForWhine.TYPE'):
        super().__init__(instance_to_wrap)



'''_737.py

SpiralBevelGearSetDesign
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs.spiral_bevel import _735, _736
from mastapy.gears.gear_designs.bevel import _916
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_GEAR_SET_DESIGN = python_net_import('SMT.MastaAPI.Gears.GearDesigns.SpiralBevel', 'SpiralBevelGearSetDesign')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelGearSetDesign',)


class SpiralBevelGearSetDesign(_916.BevelGearSetDesign):
    '''SpiralBevelGearSetDesign

    This is a mastapy class.
    '''

    TYPE = _SPIRAL_BEVEL_GEAR_SET_DESIGN

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelGearSetDesign.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def minimum_number_of_teeth_for_recommended_tooth_proportions(self) -> 'int':
        '''int: 'MinimumNumberOfTeethForRecommendedToothProportions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumNumberOfTeethForRecommendedToothProportions

    @property
    def gears(self) -> 'List[_735.SpiralBevelGearDesign]':
        '''List[SpiralBevelGearDesign]: 'Gears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Gears, constructor.new(_735.SpiralBevelGearDesign))
        return value

    @property
    def spiral_bevel_gears(self) -> 'List[_735.SpiralBevelGearDesign]':
        '''List[SpiralBevelGearDesign]: 'SpiralBevelGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpiralBevelGears, constructor.new(_735.SpiralBevelGearDesign))
        return value

    @property
    def spiral_bevel_meshes(self) -> 'List[_736.SpiralBevelGearMeshDesign]':
        '''List[SpiralBevelGearMeshDesign]: 'SpiralBevelMeshes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SpiralBevelMeshes, constructor.new(_736.SpiralBevelGearMeshDesign))
        return value
